==> apache-hop-2.8.0-src.tar.gz: apache-hop-2.8.0/plugins/tech/aws/src/main/java/org/apache/hop/pipeline/transforms/aws/sqs/SqsReaderData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.aws.sqs;

import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;

public class SqsReaderData extends BaseTransformData implements ITransformData {

    public IRowMeta outputRowMeta;
    public AwsSqsReader aws_sqs;
    public String realMessageIDFieldName;
    public String realMessageBodyFieldName;
    public String realReceiptHandleFieldName;
    public String realBodyMD5FieldName;
    public String realSQSQueue;
    public Integer realMaxMessages;
    public String realSNSMessageFieldName;

    public SqsReaderData()
    {
        super();
    }
}

==> apache-hop-2.13.0-src.tar.gz: apache-hop-2.13.0/plugins/tech/aws/src/main/java/org/apache/hop/pipeline/transforms/aws/sqs/SqsReaderData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.aws.sqs;

import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;

@SuppressWarnings("java:S1104")
public class SqsReaderData extends BaseTransformData implements ITransformData {

  public IRowMeta outputRowMeta;
  public AwsSqsReader aws_sqs;
  public String realMessageIDFieldName;
  public String realMessageBodyFieldName;
  public String realReceiptHandleFieldName;
  public String realBodyMD5FieldName;
  public String realSQSQueue;
  public Integer realMaxMessages;
  public String realSNSMessageFieldName;

  public SqsReaderData() {
    super();
  }
}
